==> fast-forward-job-hunting-0.0.3.tar.gz: fast-forward-job-hunting-0.0.3/README.md <==
[comment]: <> (.. image:: ./src/zamestnani/logo.png)
[comment]: <> (.. image:: https://raw.githubusercontent.com/greyli/flask-share/master/images/demo.png)
[comment]: <> (a reference style link.)

[//]: <> (This is also a comment.)

[//]: # (This may be the most platform independent comment)

[//]: # "Comment"
[//]: # (Comment)

[comment]: # (empty line)
[comment]: # (This actually is the most platform independent comment)
[comment]: # (Photo by Andrew Neel from Pexels)

<!---
your comment goes here
and here
-->







Fast Forward Job Hunting
========================

by Legal Machinery
------------------


Each jobseeker costs the society on average £770 per month in Universal Credit payments, which roughly totals to £1.3 billion monthly with current 1.7 million jobseekers. Every single day someone can get into employment sooner can therefore ease the burden we all bear these unprecedented days. This can be achieved by connecting jobseekers with prospective employers more efficiently and that is what we at Legal Machinery aim for.

We have just released the newest version of Fast Forward Job Hunting - a revolutionary application that greatly speeds up the process. It automatically searches for specified vacancies, evaluates which ones to apply to, tailors one's CV according to the job description and sends it to the employer. It reports the search activities to the Jobcentre as well. All that within seconds. Moreover, it can run on an affordable laptop and no one else offers such features in any case.

Fast Forward Job Hunting speeds up your job seeking efforts. It saves your time and helps you into employment significantly faster.

* Tailor your CV with a few clicks.

* Automatically search for jobs on the "Find a Job" website.

* Automatically tailor your CV to a selected job and send and an application.

* Report your job search activities to the "Universal Credit" website with one click.

![](https://gitlab.com/psmlondon/nahledy/-/raw/master/fast_forward_job_hunting_main_window.png)

(Photo by engin akyurt on Unsplash)

Structured CV database for limitless combinations:

![Structured CV database for any combinations:](https://gitlab.com/psmlondon/nahledy/-/raw/master/fast_forward_job_hunting_edit_cv_database.png)

Prepare any number of cover letters to choose from:

![Prepare any number of cover letters to choose from:](https://gitlab.com/psmlondon/nahledy/-/raw/master/fast_forward_job_hunting_edit_cover_letter.png)

Tailor your CV with a few clicks:

![Tailor your CV with a few clicks.](https://gitlab.com/psmlondon/nahledy/-/raw/master/fast_forward_job_hunting_tailor_cv.png)

Your CV tailored in seconds:

![Your CV tailored in seconds:](https://gitlab.com/psmlondon/nahledy/-/raw/master/fast_forward_job_hunting_tailored_cv.png)

## How to purchase

Get professional support for only 10 pounds per month. This includes a user manual and update notifications by email, you can pay for as many months as you wish. To purchase your registration for one month, send 10 GBP (or a multiple if you wish to prepay for more months) to account number 43201923, sort code 074456 at Nationwide, account holder Zdenek Masek. Use your email address as a payment reference. Contact us at kilodeltalima@mail.ru for enquiries. Terms and conditions apply.

## System Requirements

Fast Forward Job Hunting has been tested on GNU/Linux Debian 10 but it should run on any system with Python 3.7 or higher and the pip installation framework. The testing system has 4GB operating memory, a dual core Intel Celeron processor at about 2.4GHz and a 60GB solid state drive storage. 

With that hardware and a standard 3G unlimited mobile broadband, it checks an individual job page within approximately 12 seconds. If it decides to send an application, it takes another about 7 seconds to tailor your CV to the job description. Overall, a batch of 50 job pages usually takes roughly 10 minutes to evaluate and apply to interesting positions. Reporting sent applications to the Universal Credit account takes usually less than about a minute.

Fast Forward Job Hunting mostly consumes up to 2GB operating memory so there is a good chance it could run on an adequate Raspberry Pi model. It requires the following applications, packages and libraries:

These should be installed on your system:

* Latex, e. g. Texmaker 
* Mozilla Firefox 60 or higher
* Python 3.7 or a higher version
* geckodriver
* kwallet
* mpv
* pdfreader or similar
* pip installer
* sqlitebrowser

The installer will attempt to install the following automatically if it will not find them on your system:

* PyGObject
* keyring
* nltk
* pyperclip
* selenium
* shutil
* sklearn

These should be already part of your Python installation:

* datetime
* glob
* os
* pathlib
* pprint
* queue
* sqlite3
* stat
* subprocess
* sys
* threading
* time
* webbrowser

Installation and setup support is available upon registration purchase.

==> fast-forward-job-hunting-0.0.4.tar.gz: fast-forward-job-hunting-0.0.4/README.md <==
[comment]: <> (.. image:: ./src/zamestnani/logo.png)
[comment]: <> (.. image:: https://raw.githubusercontent.com/greyli/flask-share/master/images/demo.png)
[comment]: <> (a reference style link.)

[//]: <> (This is also a comment.)

[//]: # (This may be the most platform independent comment)

[//]: # "Comment"
[//]: # (Comment)

[comment]: # (empty line)
[comment]: # (This actually is the most platform independent comment)
[comment]: # (Photo by Andrew Neel from Pexels)

<!---
your comment goes here
and here
-->







Fast Forward Job Hunting
========================

by Legal Machinery
------------------


Each jobseeker costs the society on average £770 per month in Universal Credit payments, which roughly totals to £1.3 billion monthly with current 1.7 million jobseekers. Every single day someone can get into employment sooner can therefore ease the burden we all bear these unprecedented days. This can be achieved by connecting jobseekers with prospective employers more efficiently and that is what we at Legal Machinery aim for.

We have just released the newest version of Fast Forward Job Hunting - a revolutionary application that greatly speeds up the process. It automatically searches for specified vacancies, evaluates which ones to apply to, tailors one's CV according to the job description and sends it to the employer. It reports the search activities to the Jobcentre as well. All that within seconds. Moreover, it can run on an affordable laptop and no one else offers such features in any case.

Fast Forward Job Hunting speeds up your job seeking efforts. It saves your time and helps you into employment significantly faster.

* Tailor your CV with a few clicks.

* Automatically search for jobs on the "Find a Job" website.

* Automatically tailor your CV to a selected job and send and an application.

* Report your job search activities to the "Universal Credit" website with one click.

![](https://gitlab.com/psmlondon/nahledy/-/raw/master/fast_forward_job_hunting_main_window.png)

(Photo by engin akyurt on Unsplash)

Structured CV database for limitless combinations:

![Structured CV database for any combinations:](https://gitlab.com/psmlondon/nahledy/-/raw/master/fast_forward_job_hunting_edit_cv_database.png)

Prepare any number of cover letters to choose from:

![Prepare any number of cover letters to choose from:](https://gitlab.com/psmlondon/nahledy/-/raw/master/fast_forward_job_hunting_edit_cover_letter.png)

Tailor your CV with a few clicks:

![Tailor your CV with a few clicks.](https://gitlab.com/psmlondon/nahledy/-/raw/master/fast_forward_job_hunting_tailor_cv.png)

Your CV tailored in seconds:

![Your CV tailored in seconds:](https://gitlab.com/psmlondon/nahledy/-/raw/master/fast_forward_job_hunting_tailored_cv.png)

## How to purchase

Get professional support for only 10 pounds per month. This includes a user manual and update notifications by email, you can pay for as many months as you wish. To purchase your registration for one month, send 10 GBP (or a multiple if you wish to prepay for more months) to account number 43201923, sort code 074456 at Nationwide, account holder Zdenek Masek. Use your email address as a payment reference. Contact us at kilodeltalima@mail.ru for enquiries. Terms and conditions apply.

## Installation

Switch to command line and type "pip install fast-forward-job-hunting" without the quotation marks and press enter.

Your system needs to be connected to the Internet in order to download and install the application. Upon installation, Fast Forward Job Hunting will appear in your system's start menu under the Office group.

The below named packages are required for installation. Please purchase registration for installation and setup support.

## System Requirements

Fast Forward Job Hunting has been tested on GNU/Linux Debian 10 but it should run on any system with Python 3.7 or higher and the pip installation framework. The testing system has 4GB operating memory, a dual core Intel Celeron processor at about 2.4GHz and a 60GB solid state drive storage. 

With that hardware and a standard 3G unlimited mobile broadband, it checks an individual job page within approximately 12 seconds. If it decides to send an application, it takes another about 7 seconds to tailor your CV to the job description. Overall, a batch of 50 job pages usually takes roughly 10 minutes to evaluate and apply to interesting positions. Reporting sent applications to the Universal Credit account takes usually less than about a minute.

Fast Forward Job Hunting mostly consumes up to 2GB operating memory so there is a good chance it could run on an adequate Raspberry Pi model. It requires the following applications, packages and libraries:

These should be installed on your system:

* Latex, e. g. Texmaker 
* Mozilla Firefox 60 or higher
* Python 3.7 or a higher version
* geckodriver
* kwallet
* mpv
* pdfreader or similar
* pip installer
* sqlitebrowser

The installer will attempt to install the following automatically if it will not find them on your system:

* PyGObject
* keyring
* nltk
* pyperclip
* selenium
* shutil
* sklearn

These should be already part of your Python installation:

* datetime
* glob
* os
* pathlib
* pprint
* queue
* sqlite3
* stat
* subprocess
* sys
* threading
* time
* webbrowser

Installation and setup support is available upon registration purchase.
